function [ G ] = create_Gpgc( p, alpha, alpha_centre, p1, p2, w )
% -------------------------------------------------------------------------
%
% NAME
%
%	create_Gpgc
%
% PURPOSE
%
%	This routine creates a synthetic position-dependent gain. The domain 
%   consists of n pixels (or subpixels). The gain is taken to be 0 < alpha < 1, 
%   except in an interval between p1 and p2, where it is 0 < alpha_centre < alpha.
%   The transition between this low and high value has a half-width w.
%
% CALLING SEQUENCE
%
%	[ G ] = create_Gpgc( p, alpha, alpha_centre, p1, p2, w )
%
% INPUT PARAMETERS
%   
%   p
%     pixels
%
%   alpha, alpha_centre
%     double precision number giving the position-dependent gain at the
%     specified region
%
%   p1, p2
%     the interval where the gain is depleted
%
%   w
%     the transition half-width
%
% OUTPUT PARAMETERS
%
%   G
%     position-dependent gain factor
%     double, column vector with n elements
%
% AUTHOR
%
%   (c) Johan De Keyser - Royal Belgian Institute for Space Aeronomy - 2019
%
% HISTORY
%
%   2019-05-15 : v0.0
%     Initial version
%
% -------------------------------------------------------------------------

    % create G
    G = alpha - ( alpha - alpha_centre ) * ( 0.5*erfc( (p1-p)/w ) + 0.5*erfc( (p-p2)/w ) - 1 );

end

% =========================================================================
