function [ f ] = create_ideal_electron_spectrum( p, f_ion, w_e1, w_e2, alpha_e, dpixel )
% -------------------------------------------------------------------------
%
% NAME
%
%	create_ideal_electron_spectrum
%
% PURPOSE
%
%	This routine creates a synthetic electron spectrum for a given
%   ion spectrum, with the prescribed electron cascade properties, 
%   and assuming perfect MCP gain.
%
% CALLING SEQUENCE
%
%	[ f ] = create_ideal_electron_spectrum( p, f_ion, w_e1, w_e2, alpha_e, dpixel )
%
% INPUT PARAMETERS
%   
%   p
%     pixel vector
%
%   f_ion
%     ion spectrum
%
%   w_e1, w_e2, alpha_e
%     half-widths of both Gaussian components and relative importance of
%     the secondary Gaussian in the electron cascade
%
%   dpixel
%     half-width in pixels of the spread due to misalignment of analysis
%     direction and LEDA row orientation
%
% OUTPUT PARAMETERS
%
%   f
%     synthetic ideal electron spectrum, same format as p
%
% AUTHOR
%
%   (c) Johan De Keyser - Royal Belgian Institute for Space Aeronomy - 2019
%
% HISTORY
%
%   2019-05-15 : v0.0
%     Initial version
%
% -------------------------------------------------------------------------
    
    % create the electron spectrum assuming no detector ageing
    f = create_LEDA_electron_spectrum( p, f_ion, w_e1, w_e2, alpha_e, dpixel, ones(size(p)) );
    
end

% =========================================================================
