function [ frestored, f_ion ] = restore_LEDA_electron_spectrum( p, f, w_e1, w_e2, alpha_e, dpixel, Gpgc, SN )
% -------------------------------------------------------------------------
%
% NAME
%
%	restore_LEDA_electron_spectrum
%
% PURPOSE
%
%	This routine restores a synthetic LEDA electron spectrum to eliminate
%   the effects of the position-dependent MCP gain.
%
% CALLING SEQUENCE
%
%	[ frestored, f_ion ] = restore_LEDA_electron_spectrum( p, f, w_e1, w_e2, alpha_e, dpixel, Gpgc, SN )
%
% INPUT PARAMETERS
%   
%   p
%     pixel vector
%
%   f
%     recorded LEDA electron spectrum
%
%   w_e1, w_e2, alpha_e
%     half-widths of both Gaussian components and relative importance of
%     the secondary Gaussian in the electron cascade
%
%   dpixel
%     half-width in pixels of the spread due to misalignment of analysis
%     direction and LEDA row orientation
%
%   Gpgc
%     position-dependent gain factor
%
%   SN
%     signal to noise ratio
%
% OUTPUT PARAMETERS
%
%   frestored
%     restored electron spectrum, same format as p
%
%   f_ion
%     restored ion spectrum, same format as p
%
% AUTHOR
%
%   (c) Johan De Keyser - Royal Belgian Institute for Space Aeronomy - 2019
%
% HISTORY
%
%   2019-05-15 : v0.0
%     Initial version
%
% -------------------------------------------------------------------------
    
    % compute ion spectrum (backward problem)
    f_ion = compute_ion_spectrum_from_LEDA_electron_spectrum( p, f, w_e1, w_e2, alpha_e, dpixel, Gpgc, SN );
    
    % compute corresponding electron spectrum in the absence of gain
    % degradation
    frestored = create_ideal_electron_spectrum( p, f_ion, w_e1, w_e2, alpha_e, dpixel );
        
end

% =========================================================================
